@@ -8,20 +8,39 @@ use response;
 use request::RequestBuilder;
 use request::DoRequest;
 
-// name (true)  String           The human-readable string you wish to use when displaying the
-//                               Droplet name. The name, if set to a domain name managed in the
-//                               DigitalOcean DNS management system, will configure a PTR record
-//                               for the Droplet. The name set during creation will also determine
-//                               the hostname for the Droplet in its internal configuration.
-// region (true) String          The unique slug id for the region that you wish to deploy in
-// size (true)   String          The unique slug identifier for the size that you wish to select
+// name (true)  String           The human-readable string you wish to use when
+// displaying the
+// Droplet name. The name, if set to a domain
+// name managed in the
+// DigitalOcean DNS management system, will
+// configure a PTR record
+// for the Droplet. The name set during creation
+// will also determine
+// the hostname for the Droplet in its internal
+// configuration.
+// region (true) String          The unique slug id for the region that you
+// wish to deploy in
+// size (true)   String          The unique slug identifier for the size that
+// you wish to select
 //                               for this Droplet.
-// image         number (if using an image ID), or String (if using a public image slug) The image ID of a public or private image, or the unique slug identifier for a public image. This image will be the base image for your Droplet.    true
-// ssh_keys      Array           An array containing the IDs or fingerprints of the SSH keys that you wish to embed in the Droplet's root account upon creation.
-// backups       Boolean         A boolean indicating whether automated backups should be enabled for the Droplet. Automated backups can only be enabled when the Droplet is created.
-// ipv6          Boolean         A boolean indicating whether IPv6 is enabled on the Droplet.
-// private_networking  Boolean  A boolean indicating whether private networking is enabled for the Droplet. Private networking is currently only available in certain regions.
-// user_data     String          A string of the desired User Data for the Droplet. User Data is currently only available in regions with metadata listed in their features.
+// image         number (if using an image ID), or String (if using a public
+// image slug) The image ID of a public or private image, or the unique slug
+// identifier for a public image. This image will be the base image for your
+// Droplet.    true
+// ssh_keys      Array           An array containing the IDs or fingerprints of
+// the SSH keys that you wish to embed in the Droplet's root account upon
+// creation.
+// backups       Boolean         A boolean indicating whether automated backups
+// should be enabled for the Droplet. Automated backups can only be enabled
+// when the Droplet is created.
+// ipv6          Boolean         A boolean indicating whether IPv6 is enabled
+// on the Droplet.
+// private_networking  Boolean  A boolean indicating whether private networking
+// is enabled for the Droplet. Private networking is currently only available
+// in certain regions.
+// user_data     String          A string of the desired User Data for the
+// Droplet. User Data is currently only available in regions with metadata
+// listed in their features.
 #[derive(Serialize)]
 pub struct Droplet {
     pub name: String,
@@ -32,7 +51,7 @@ pub struct Droplet {
     pub backups: bool,
     pub ipv6: bool,
     pub private_networking: bool,
-    pub user_data: Option<String>
+    pub user_data: Option<String>,
 }
 
 #[derive(Serialize)]
@@ -45,7 +64,7 @@ struct DropletWithId {
     pub backups: bool,
     pub ipv6: bool,
     pub private_networking: bool,
-    pub user_data: Option<String>
+    pub user_data: Option<String>,
 }
 
 impl DropletWithId {
@@ -59,7 +78,7 @@ impl DropletWithId {
             backups: d.backups,
             ipv6: d.ipv6,
             private_networking: d.private_networking,
-            user_data: d.user_data.clone()
+            user_data: d.user_data.clone(),
         }
     }
 }
@@ -67,7 +86,7 @@ impl DropletWithId {
 impl fmt::Display for Droplet {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f,
-            "Name: {}\n\
+               "Name: {}\n\
              Region: {}\n\
              Size: {}\n\
              Image: {}\n\
@@ -76,31 +95,30 @@ impl fmt::Display for Droplet {
              IPv6 Enabled: {}\n\
              Private Networking Enabled: {}\n\
              User Data: {}\n",
-             self.name,
-             self.region,
-             self.size,
-             self.image,
-             if let Some(ref v) = self.ssh_keys {
-                v.iter().fold(String::new(), |acc, s| acc + &format!(" {},", s)[..])
-             } else {
-                "None".to_owned()
-             },
-             self.backups,
-             self.ipv6,
-             self.private_networking,
-             if let Some(d) = self.user_data.clone() {
-                d
-             } else {
-                "None".to_owned()
-             }
-        )
+               self.name,
+               self.region,
+               self.size,
+               self.image,
+               if let Some(ref v) = self.ssh_keys {
+                   v.iter().fold(String::new(), |acc, s| acc + &format!(" {},", s)[..])
+               } else {
+                   "None".to_owned()
+               },
+               self.backups,
+               self.ipv6,
+               self.private_networking,
+               if let Some(d) = self.user_data.clone() {
+                   d
+               } else {
+                   "None".to_owned()
+               })
     }
 }
 
 impl fmt::Display for DropletWithId {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f,
-            "Name: {}\n\
+               "Name: {}\n\
              Region: {}\n\
              Size: {}\n\
              Image: {}\n\
@@ -109,24 +127,23 @@ impl fmt::Display for DropletWithId {
              IPv6 Enabled: {}\n\
              Private Networking Enabled: {}\n\
              User Data: {}\n",
-             self.name,
-             self.region,
-             self.size,
-             self.image,
-             if let Some(ref v) = self.ssh_keys {
-                v.iter().fold(String::new(), |acc, s| acc + &format!(" {},", s)[..])
-             } else {
-                "None".to_owned()
-             },
-             self.backups,
-             self.ipv6,
-             self.private_networking,
-             if let Some(d) = self.user_data.clone() {
-                d
-             } else {
-                "None".to_owned()
-             }
-        )
+               self.name,
+               self.region,
+               self.size,
+               self.image,
+               if let Some(ref v) = self.ssh_keys {
+                   v.iter().fold(String::new(), |acc, s| acc + &format!(" {},", s)[..])
+               } else {
+                   "None".to_owned()
+               },
+               self.backups,
+               self.ipv6,
+               self.private_networking,
+               if let Some(d) = self.user_data.clone() {
+                   d
+               } else {
+                   "None".to_owned()
+               })
     }
 }
 
@@ -141,7 +158,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"disable_backups\"}}"))
+            body: Some(format!("{{\"type\":\"disable_backups\"}}")),
         }
     }
     pub fn reboot(mut self) -> RequestBuilder<'t, response::Action> {
@@ -154,7 +171,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"reboot\"}}"))
+            body: Some(format!("{{\"type\":\"reboot\"}}")),
         }
     }
     pub fn power_cycle(mut self) -> RequestBuilder<'t, response::Action> {
@@ -167,7 +184,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"power_cycle\"}}"))
+            body: Some(format!("{{\"type\":\"power_cycle\"}}")),
         }
     }
     pub fn shutdown(mut self) -> RequestBuilder<'t, response::Action> {
@@ -180,7 +197,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"shutdown\"}}"))
+            body: Some(format!("{{\"type\":\"shutdown\"}}")),
         }
     }
     pub fn power_off(mut self) -> RequestBuilder<'t, response::Action> {
@@ -193,7 +210,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"power_off\"}}"))
+            body: Some(format!("{{\"type\":\"power_off\"}}")),
         }
     }
     pub fn power_on(mut self) -> RequestBuilder<'t, response::Action> {
@@ -206,7 +223,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"power_on\"}}"))
+            body: Some(format!("{{\"type\":\"power_on\"}}")),
         }
     }
     pub fn restore(mut self, img: &str) -> RequestBuilder<'t, response::Action> {
@@ -216,15 +233,15 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
         //      "image": 12356          // number if ID, string if slug
         self.url.push_str("/actions");
         let image = match img.parse::<u64>() {
-            Ok(_)  => img.to_string(),
-            Err(_) => format!("\"{}\"", img)
+            Ok(_) => img.to_string(),
+            Err(_) => format!("\"{}\"", img),
         };
         RequestBuilder {
             method: Method::Post,
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"restore\",\"image\":{}}}", image))
+            body: Some(format!("{{\"type\":\"restore\",\"image\":{}}}", image)),
         }
     }
     pub fn reset_password(mut self) -> RequestBuilder<'t, response::Action> {
@@ -237,7 +254,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"password_reset\"}}"))
+            body: Some(format!("{{\"type\":\"password_reset\"}}")),
         }
     }
     pub fn resize(mut self, size: &str, disk: bool) -> RequestBuilder<'t, response::Action> {
@@ -252,7 +269,9 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"resize\",\"disk\":{},\"size\":{:?}}}", disk.to_string(), size))
+            body: Some(format!("{{\"type\":\"resize\",\"disk\":{},\"size\":{:?}}}",
+                               disk.to_string(),
+                               size)),
         }
     }
     pub fn rebuild(mut self, img: &str) -> RequestBuilder<'t, response::Action> {
@@ -262,15 +281,15 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
         //      "image": 12356          // number if ID, string if slug
         self.url.push_str("/actions");
         let image = match img.parse::<u64>() {
-            Ok(_)  => img.to_string(),
-            Err(_) => format!("\"{}\"", img)
+            Ok(_) => img.to_string(),
+            Err(_) => format!("\"{}\"", img),
         };
         RequestBuilder {
             method: Method::Post,
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"rebuild\",\"image\":{}}}", image))
+            body: Some(format!("{{\"type\":\"rebuild\",\"image\":{}}}", image)),
         }
     }
     pub fn rename(mut self, name: &str) -> RequestBuilder<'t, response::Action> {
@@ -284,7 +303,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"rename\",\"name\":{:?}}}", name))
+            body: Some(format!("{{\"type\":\"rename\",\"name\":{:?}}}", name)),
         }
     }
     pub fn change_kernel(mut self, kernel: &str) -> RequestBuilder<'t, response::Action> {
@@ -298,7 +317,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"change_kernel\",\"kernel\":{}}}", kernel))
+            body: Some(format!("{{\"type\":\"change_kernel\",\"kernel\":{}}}", kernel)),
         }
     }
     pub fn enable_ipv6(mut self) -> RequestBuilder<'t, response::Action> {
@@ -311,7 +330,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"enable_ipv6\"}}"))
+            body: Some(format!("{{\"type\":\"enable_ipv6\"}}")),
         }
     }
     pub fn enable_private_networking(mut self) -> RequestBuilder<'t, response::Action> {
@@ -324,7 +343,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"enable_private_networking\"}}"))
+            body: Some(format!("{{\"type\":\"enable_private_networking\"}}")),
         }
     }
     pub fn snapshot(mut self, name: &str) -> RequestBuilder<'t, response::Action> {
@@ -338,7 +357,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"snapshot\",\"name\":{:?}}}", name))
+            body: Some(format!("{{\"type\":\"snapshot\",\"name\":{:?}}}", name)),
         }
     }
     pub fn upgrade(mut self) -> RequestBuilder<'t, response::Action> {
@@ -351,7 +370,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(format!("{{\"type\":\"upgrade\"}}"))
+            body: Some(format!("{{\"type\":\"upgrade\"}}")),
         }
     }
     pub fn action(mut self, id: &str) -> RequestBuilder<'t, response::Action> {
@@ -387,7 +406,7 @@ impl<'t> RequestBuilder<'t, response::Droplet> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: None
+            body: None,
         }
     }
     pub fn show(&self) -> RequestBuilder<'t, response::Droplet> {
@@ -423,8 +442,8 @@ impl<'t> RequestBuilder<'t, response::Droplets> {
                 auth: self.auth,
                 url: self.url,
                 resp_t: PhantomData,
-                body: Some(serde_json::to_string(&d).ok().unwrap())
-            }
+                body: Some(serde_json::to_string(&d).ok().unwrap()),
+            };
         }
 
         RequestBuilder {
@@ -432,17 +451,19 @@ impl<'t> RequestBuilder<'t, response::Droplets> {
             auth: self.auth,
             url: self.url,
             resp_t: PhantomData,
-            body: Some(serde_json::to_string(droplet).ok().unwrap())
+            body: Some(serde_json::to_string(droplet).ok().unwrap()),
         }
 
     }
     pub fn neighbors(self) -> RequestBuilder<'t, response::Neighbors> {
         // GET: "https://api.digitalocean.com/v2/reports/droplet_neighbors"
-        RequestBuilder::new(self.auth, "https://api.digitalocean.com/v2/reports/droplet_neighbors")
+        RequestBuilder::new(self.auth,
+                            "https://api.digitalocean.com/v2/reports/droplet_neighbors")
     }
     pub fn upgrades(self) -> RequestBuilder<'t, response::ResponseStringArray> {
         // GET: "https://api.digitalocean.com/v2/droplet_upgrades"
-        RequestBuilder::new(self.auth, "https://api.digitalocean.com/v2/droplet_upgrades")
+        RequestBuilder::new(self.auth,
+                            "https://api.digitalocean.com/v2/droplet_upgrades")
     }
 }
 
