@@ -1,9 +1,9 @@
 pub use self::account::Account;
-pub use self::action::{Actions, Action};
+pub use self::action::{Action, Actions};
 pub use self::backup::{Backup, Backups};
-pub use self::domain::{Domains, Domain};
+pub use self::domain::{Domain, Domains};
 pub use self::dns::{DnsRecord, DnsRecords};
-pub use self::droplet::{Droplets, Droplet};
+pub use self::droplet::{Droplet, Droplets};
 pub use self::error::DoError;
 pub use self::header::HeaderOnly;
 pub use self::image::{Image, Images};
@@ -12,12 +12,12 @@ pub use self::links::Links;
 pub use self::meta::Meta;
 pub use self::namedresponse::NamedResponse;
 pub use self::neighbors::Neighbors;
-pub use self::network::{Networks, Network};
-pub use self::page::{Pages, RawPagedResponse, NewIter};
-pub use self::region::{Regions, Region};
-pub use self::size::{Sizes, Size};
+pub use self::network::{Network, Networks};
+pub use self::page::{NewIter, Pages, RawPagedResponse};
+pub use self::region::{Region, Regions};
+pub use self::size::{Size, Sizes};
 pub use self::snapshot::{Snapshot, Snapshots};
-pub use self::ssh_key::{SshKeys, SshKey};
+pub use self::ssh_key::{SshKey, SshKeys};
 pub use self::upgrades::{DropletUpgrade, DropletUpgrades, ResponseStringArray};
 
 mod account;
@@ -43,4 +43,4 @@ mod region;
 mod size;
 mod upgrades;
 
-pub trait NotArray {}
\ No newline at end of file
+pub trait NotArray {}
